@@ -39,6 +39,7 @@
 #include <QComboBox>
 #include <QSpinBox>
 #include <QGridLayout>
+#include <QFileSystemWatcher>
 
 #include <gta/gta.hpp>
 
@@ -188,8 +189,8 @@ Q_OBJECT
 
 private:
     MyTabWidget *_files_widget;
-    QDir _last_file_open_dir;
-    QDir _last_file_save_as_dir;
+    QFileSystemWatcher* _files_watcher;
+    QDir _last_dir;
 
     bool check_have_file();
     bool check_file_unchanged();
@@ -205,6 +206,8 @@ private:
 
 private slots:
     void file_changed(const std::string &file_name, const std::string &save_name);
+    void file_changed_on_disk(const QString& name);
+    void tab_close(int index);
 
 protected:
     void closeEvent(QCloseEvent *event);	
@@ -213,7 +216,7 @@ public:
     GUI();
     ~GUI();
 
-    void open(const std::string &file_name, const std::string &save_name);
+    void open(const std::string &file_name, const std::string &save_name, int tab_index = -1);
 
 private slots:
     void file_open();
