@@ -34,9 +34,9 @@
 
 #include <gta/gta.hpp>
 
-#include "msg.h"
-#include "opt.h"
-#include "dbg.h"
+#include "base/msg.h"
+#include "base/opt.h"
+#include "base/dbg.h"
 
 #include "lib.h"
 #include "cmds.h"
@@ -151,7 +151,7 @@ extern "C" int gtatool_help(int argc, char *argv[])
         }
         msg::req_txt(
                 "\n"
-                "Commands marked with [u] are unavailable.\n"
+                "Commands marked with [u] are unavailable in this installation.\n"
                 "Use \"%s help <command>\" for command specific help.\n"
                 "Report bugs to <%s>.", program_name, PACKAGE_BUGREPORT);
         return 0;
