@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 
-# Copyright (C) 2012
+# Copyright (C) 2012, 2013
 # Martin Lambers <marlam@marlam.de>
 #
 # Copying and distribution of this file, with or without modification, are
@@ -19,4 +19,11 @@ $GTA create -d 10,10 -c uint8 -v 117 "$TMPD"/b.gta
 $GTA component-compute -e 'c0=42' "$TMPD"/b.gta > "$TMPD"/c.gta
 cmp "$TMPD"/a.gta "$TMPD"/c.gta
 
+$GTA create -d 10 -n5 > "$TMPD"/empty0.gta
+$GTA create -c uint8 -n5 > "$TMPD"/empty1.gta
+$GTA component-compute -e '5' "$TMPD"/empty0.gta > "$TMPD"/xempty0.gta
+cmp "$TMPD"/empty0.gta "$TMPD"/xempty0.gta
+$GTA component-compute -e 'c0=3' "$TMPD"/empty1.gta > "$TMPD"/xempty1.gta
+cmp "$TMPD"/empty1.gta "$TMPD"/xempty1.gta
+
 rm -r "$TMPD"
